summaryrefslogtreecommitdiffstats
path: root/sqlglot/schema.py
diff options
context:
space:
mode:
Diffstat (limited to 'sqlglot/schema.py')
-rw-r--r--sqlglot/schema.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/sqlglot/schema.py b/sqlglot/schema.py
index 1fd4025..dbd0caa 100644
--- a/sqlglot/schema.py
+++ b/sqlglot/schema.py
@@ -49,7 +49,7 @@ class Schema(abc.ABC):
only_visible: bool = False,
dialect: DialectType = None,
normalize: t.Optional[bool] = None,
- ) -> t.List[str]:
+ ) -> t.Sequence[str]:
"""
Get the column names for a table.
@@ -60,7 +60,7 @@ class Schema(abc.ABC):
normalize: whether to normalize identifiers according to the dialect of interest.
Returns:
The list of column names.
"""
@abc.abstractmethod
@@ -60,7 +60,7 @@ class Schema(abc.ABC):
normalize: whether to normalize identifiers according to the dialect of interest.
Returns:
- The list of column names.
+ The sequence of column names.
"""